import {
  ChartAnnotation,
  ChartSettings,
  EntityType,
  getEntityProperty,
  mergeOptions,
  QueryReturn
} from '@metad/ocap-core'
import { EChartsOptions } from './types'

export function Funnel(
  data: QueryReturn<unknown>,
  chartAnnotation: ChartAnnotation,
  entityType: EntityType,
  settings: ChartSettings,
  options: EChartsOptions
) {
  const item = data.data[0]

  const series = {
    name: 'Funnel',
    type: 'funnel',
    minSize: '20%',
    maxSize: '100%',
    data: chartAnnotation.measures.map((measure) => {
      const property = getEntityProperty(entityType, measure)
      return {
        value: item[measure.measure],
        name: property.label || property.name
      }
    })
  }

  const funnelOptions = {
    tooltip: mergeOptions(
      {
        trigger: 'item'
      },
      options?.tooltip
    ),
    series: [mergeOptions(series, options?.seriesStyle)]
  }

  return funnelOptions
}
