import { ChartMeasure, Property } from '@metad/ocap-core'
import { maxBy, minBy, range } from 'lodash-es'
import { getChromaticScale } from './chromatics'
import { IDataset, IVisualMap, SeriesComponentType } from './types'

export function getColorLightnessVisualMap(
  measure: ChartMeasure,
  property: Property,
  dataset: IDataset['dataset'] | IDataset['dataset'][],
  visualMaps?: IVisualMap[]
) {
  const _dataset = Array.isArray(dataset) ? dataset[0] : dataset
  const dataMin = minBy(_dataset.source, measure.measure)?.[measure.measure]
  const dataMax = maxBy(_dataset.source, measure.measure)?.[measure.measure]

  // const visualMap = visualMaps?.find((item) => item.type === 'continuous') ?? {}

  return {
    dimension: _dataset.dimensions ? _dataset.dimensions.indexOf(measure.measure) : measure.measure,
    min: dataMin,
    max: dataMax,
    // itemHeight: 120,
    text: [property.label || property.name]
    // textGap: 30,
    // inRange: {
    //   colorLightness: [0.9, 0.5]
    // },
    // outOfRange: {
    //   color: ['rgba(255,255,255,0.4)']
    // },
    // controller: {
    //   inRange: {
    //     color: ['#c23531']
    //   },
    //   outOfRange: {
    //     color: ['#999']
    //   }
    // },
    // ...visualMap
  }
}

export function getMeasurePaletteVisualMap(measure: SeriesComponentType, data: any[]) {
  const dataMin = minBy(data, measure.measure)?.[measure.measure]
  const dataMax = maxBy(data, measure.measure)?.[measure.measure]

  const domain = measure.domain || [measure.dataMin, measure.dataMax]
  const colorFun: any = getChromaticScale(measure.palette.name, [0, measure.dataSize - 1], measure.palette.reverse)

  const inRange = { color: [] }
  inRange.color = range(measure.dataSize).map((i) => colorFun(i))

  return {
    show: false,
    type: 'continuous',
    text: [measure.property.label || measure.property.name],
    min: dataMin,
    max: dataMax,
    inRange
  }
}
